﻿using System.Collections.Generic;
using System.Linq;
using System.Windows.Controls;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Charting;

namespace SilverlightApplication1
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();

            RadChart1.LayoutUpdated += this.RadChart1_LayoutUpdated;
        }

        private void RadChart1_LayoutUpdated(object sender, System.EventArgs e)
        {
            RadChart1.LayoutUpdated -= this.RadChart1_LayoutUpdated;

            var plotAreaPanel = RadChart1.DefaultView.ChartArea.ChildrenOfType<ClipPanel>().FirstOrDefault();

            plotAreaPanel.MouseEnter += this.plotAreaPanel_MouseEnter;
            plotAreaPanel.MouseMove += this.PlotArea_MouseMove;
            plotAreaPanel.MouseLeave += this.plotAreaPanel_MouseLeave;
        }

        private void plotAreaPanel_MouseEnter(object sender, System.Windows.Input.MouseEventArgs e)
        {
            RadChart1.DefaultView.ChartArea.Annotations[0].Visibility = System.Windows.Visibility.Visible;
            RadChart1.DefaultView.ChartArea.Annotations[1].Visibility = System.Windows.Visibility.Visible;
        }

        private void PlotArea_MouseMove(object sender, System.Windows.Input.MouseEventArgs e)
        {
            var plotAreaPanel = sender as ClipPanel;
            var position = e.GetPosition(plotAreaPanel);

            var x = RadChart1.DefaultView.ChartArea.AxisX.ConvertPhysicalUnitsToData(position.X);
            var y = RadChart1.DefaultView.ChartArea.AxisY.ConvertPhysicalUnitsToData(position.Y);

            (this.DataContext as ViewModel).X = x;
            (this.DataContext as ViewModel).Y = y;
        }

        private void plotAreaPanel_MouseLeave(object sender, System.Windows.Input.MouseEventArgs e)
        {
            RadChart1.DefaultView.ChartArea.Annotations[0].Visibility = System.Windows.Visibility.Collapsed;
            RadChart1.DefaultView.ChartArea.Annotations[1].Visibility = System.Windows.Visibility.Collapsed;
        }
    }

    public class ViewModel : ViewModelBase
    {
        private List<ChartData> data;
        private double y;
        private double x;

        public ViewModel()
        {
            this.Data = this.GetData();
        }

        public List<ChartData> Data
        {
            get
            {
                return this.data;
            }
            set
            {
                if (this.data != value)
                {
                    this.data = value;
                    this.OnPropertyChanged("Data");
                }
            }
        }

        public double X
        {
            get
            {
                return this.x;
            }
            set
            {
                if (this.x != value)
                {
                    this.x = value;
                    this.OnPropertyChanged("X");
                }
            }
        }

        public double Y
        {
            get
            {
                return this.y;
            }
            set
            {
                if (this.y != value)
                {
                    this.y = value;
                    this.OnPropertyChanged("Y");
                }
            }
        }

        private List<ChartData> GetData()
        {
            List<ChartData> data = new List<ChartData>();
            data.Add(new ChartData() { YValue = 10 });
            data.Add(new ChartData() { YValue = 20 });
            data.Add(new ChartData() { YValue = 11 });
            data.Add(new ChartData() { YValue = 12 });
            data.Add(new ChartData() { YValue = 5 });
            data.Add(new ChartData() { YValue = 7 });
            data.Add(new ChartData() { YValue = 11 });
            data.Add(new ChartData() { YValue = 13 });

            return data;
        }
    }

    public class ChartData
    {
        public double YValue
        {
            get;
            set;
        }
    }
}
